django-migration-docs
########################################################################

Documentation
=============

`View the django-migration-docs docs here
<https://django-migration-docs.readthedocs.io/>`_.

Installation
============

Install django-migration-docs with::

    pip3 install django-migration-docs

After this, add ``migration_docs`` to the ``INSTALLED_APPS``
setting of your Django project.

Contributing Guide
==================

For information on setting up django-migration-docs for development and
contributing changes, view `CONTRIBUTING.rst <CONTRIBUTING.rst>`_.


Primary Authors
===============

- @juemura (Juliana de Heer)
- @wesleykendall (Wes Kendall)
- @tomage (Tómas Árni Jónasson)
